==> camel-k-model-v1-6.6.2-sources.jar: io/fabric8/camelk/v1/ServerFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServerFluentImpl<A extends ServerFluent<A>> extends BaseFluent<A> implements ServerFluent<A>{
  public ServerFluentImpl() {
  }
  public ServerFluentImpl(Server instance) {
    this.withConfiguration(instance.getConfiguration()); 
    this.withId(instance.getId()); 
    this.withPassword(instance.getPassword()); 
    this.withUsername(instance.getUsername()); 
  }
  private Map<String,String> configuration;
  private String id;
  private String password;
  private String username;
  public A addToConfiguration(String key,String value) {
    if(this.configuration == null && key != null && value != null) { this.configuration = new LinkedHashMap(); }
    if(key != null && value != null) {this.configuration.put(key, value);} return (A)this;
  }
  public A addToConfiguration(Map<String,String> map) {
    if(this.configuration == null && map != null) { this.configuration = new LinkedHashMap(); }
    if(map != null) { this.configuration.putAll(map);} return (A)this;
  }
  public A removeFromConfiguration(String key) {
    if(this.configuration == null) { return (A) this; }
    if(key != null && this.configuration != null) {this.configuration.remove(key);} return (A)this;
  }
  public A removeFromConfiguration(Map<String,String> map) {
    if(this.configuration == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.configuration != null){this.configuration.remove(key);}}} return (A)this;
  }
  public Map<String,String> getConfiguration() {
    return this.configuration;
  }
  public <K,V>A withConfiguration(Map<String,String> configuration) {
    if (configuration == null) { this.configuration =  null;} else {this.configuration = new LinkedHashMap(configuration);} return (A) this;
  }
  public Boolean hasConfiguration() {
    return this.configuration != null;
  }
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public String getPassword() {
    return this.password;
  }
  public A withPassword(String password) {
    this.password=password; return (A) this;
  }
  public Boolean hasPassword() {
    return this.password != null;
  }
  public String getUsername() {
    return this.username;
  }
  public A withUsername(String username) {
    this.username=username; return (A) this;
  }
  public Boolean hasUsername() {
    return this.username != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServerFluentImpl that = (ServerFluentImpl) o;
    if (configuration != null ? !configuration.equals(that.configuration) :that.configuration != null) return false;
    if (id != null ? !id.equals(that.id) :that.id != null) return false;
    if (password != null ? !password.equals(that.password) :that.password != null) return false;
    if (username != null ? !username.equals(that.username) :that.username != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configuration,  id,  password,  username,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configuration != null && !configuration.isEmpty()) { sb.append("configuration:"); sb.append(configuration + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (username != null) { sb.append("username:"); sb.append(username); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/ServerFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServerFluentImpl<A extends ServerFluent<A>> extends BaseFluent<A> implements ServerFluent<A>{
  public ServerFluentImpl() {
  }
  public ServerFluentImpl(Server instance) {
    if (instance != null) {
      this.withConfiguration(instance.getConfiguration());
      this.withId(instance.getId());
      this.withPassword(instance.getPassword());
      this.withUsername(instance.getUsername());
    }
  }
  private Map<String,String> configuration;
  private String id;
  private String password;
  private String username;
  public A addToConfiguration(String key,String value) {
    if(this.configuration == null && key != null && value != null) { this.configuration = new LinkedHashMap(); }
    if(key != null && value != null) {this.configuration.put(key, value);} return (A)this;
  }
  public A addToConfiguration(Map<String,String> map) {
    if(this.configuration == null && map != null) { this.configuration = new LinkedHashMap(); }
    if(map != null) { this.configuration.putAll(map);} return (A)this;
  }
  public A removeFromConfiguration(String key) {
    if(this.configuration == null) { return (A) this; }
    if(key != null && this.configuration != null) {this.configuration.remove(key);} return (A)this;
  }
  public A removeFromConfiguration(Map<String,String> map) {
    if(this.configuration == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.configuration != null){this.configuration.remove(key);}}} return (A)this;
  }
  public Map<String,String> getConfiguration() {
    return this.configuration;
  }
  public <K,V>A withConfiguration(Map<String,String> configuration) {
    if (configuration == null) { this.configuration =  null;} else {this.configuration = new LinkedHashMap(configuration);} return (A) this;
  }
  public Boolean hasConfiguration() {
    return this.configuration != null;
  }
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public String getPassword() {
    return this.password;
  }
  public A withPassword(String password) {
    this.password=password; return (A) this;
  }
  public Boolean hasPassword() {
    return this.password != null;
  }
  public String getUsername() {
    return this.username;
  }
  public A withUsername(String username) {
    this.username=username; return (A) this;
  }
  public Boolean hasUsername() {
    return this.username != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServerFluentImpl that = (ServerFluentImpl) o;
    if (!java.util.Objects.equals(configuration, that.configuration)) return false;

    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(password, that.password)) return false;

    if (!java.util.Objects.equals(username, that.username)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configuration,  id,  password,  username,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configuration != null && !configuration.isEmpty()) { sb.append("configuration:"); sb.append(configuration + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (username != null) { sb.append("username:"); sb.append(username); }
    sb.append("}");
    return sb.toString();
  }
  
}
